@@ -12,9 +12,9 @@ from uuid import uuid4, UUID
 from requests import get, Response, RequestException
 from termcolor import colored
 
-__version__ = "1.0.3"
+__version__ = "1.0.4"
 __accepted_versions__ = [
-    "1.0", "1.0.3"
+    "1.0", "1.0.4"
 ]
 __directory__ = dirname(__file__)
 
@@ -238,8 +238,6 @@ class API:
         else:
             raise TypeError("Update function requires a config.urmapi.json file.")
 
-                    
-
 class Ledger:
     """
     Manages the ledger JSON file.
@@ -383,15 +381,15 @@ class Ledger:
 
         :return: None
         """
-        for package in self.ledger:
-            print(f"{package['name']} Scanning...")
+        for package_id, package_data in self.ledger.copy().items():
+            print(f"{package_data['name']} Scanning...")
             
-            if exists(package["location"]) and exists(join(package["location"], "config.urmapi.json")):
-                print(colored(f"{package['name']}: Exists", "green"))
+            if exists(package_data["location"]) and exists(join(package_data["location"], "config.urmapi.json")):
+                print(colored(f"{package_data['name']}: Exists", "green"))
 
             else:
-                print(colored(f"{package['name']}: Could not be found. Removing...", "red"))
-                self.remove(package)
+                print(colored(f"{package_data['name']}: Could not be found. Removing...", "red"))
+                self.remove(package_id)
 
         print("Scan completed. Implementing changes...")
         self.implement()
